@@ -16,7 +16,7 @@
 from gettext import gettext as _
 import logging
 
-from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import Gio
@@ -94,7 +94,7 @@ class HomeWindow(Gtk.Window):
         self._toolbar.show_view_buttons()
 
         # Loads the Gsettings value for activity 'resume-mode'
-        setting = Gio.Settings('org.sugarlabs.user')
+        setting = Gio.Settings.new('org.sugarlabs.user')
         self._resume_mode = setting.get_boolean('resume-activity')
         self._home_box.set_resume_mode(self._resume_mode)
 
@@ -185,8 +185,8 @@ class HomeWindow(Gtk.Window):
     def __key_press_event_cb(self, window, event):
         if self.__is_alt(event) and not self._alt_timeout_sid:
             self._home_box.set_resume_mode(not self._resume_mode)
-            self._alt_timeout_sid = GObject.timeout_add(100,
-                                                        self.__alt_timeout_cb)
+            self._alt_timeout_sid = GLib.timeout_add(100,
+                                                     self.__alt_timeout_cb)
 
         if not self._toolbar.search_entry.props.has_focus:
             self._toolbar.search_entry.grab_focus()
@@ -196,7 +196,7 @@ class HomeWindow(Gtk.Window):
     def __key_release_event_cb(self, window, event):
         if self.__is_alt(event) and self._alt_timeout_sid:
             self._home_box.set_resume_mode(self._resume_mode)
-            GObject.source_remove(self._alt_timeout_sid)
+            GLib.source_remove(self._alt_timeout_sid)
             self._alt_timeout_sid = None
 
         return False
@@ -210,7 +210,7 @@ class HomeWindow(Gtk.Window):
         self._home_box.set_resume_mode(self._resume_mode)
 
         if self._alt_timeout_sid:
-            GObject.source_remove(self._alt_timeout_sid)
+            GLib.source_remove(self._alt_timeout_sid)
             self._alt_timeout_sid = None
 
         return False
